@@ -44,7 +44,7 @@ from update_checker import update_check
 from warnings import simplefilter, warn, warn_explicit
 
 
-__version__ = '2.1.9'
+__version__ = '2.1.10'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -113,6 +113,7 @@ class Config(object):  # pylint: disable-msg=R0903, R0924
                  'my_mod_subreddits':   'subreddits/mine/moderator/',
                  'my_subreddits':       'subreddits/mine/subscriber/',
                  'new':                 'new/',
+                 'new_subreddits':      'subreddits/new/',
                  'marknsfw':            'api/marknsfw/',
                  'popular_subreddits':  'subreddits/popular/',
                  'read_message':        'api/read_message/',
@@ -786,6 +787,16 @@ class UnauthenticatedReddit(BaseReddit):
         """
         return self.get_content(self.config['new'], *args, **kwargs)
 
+    def get_new_subreddits(self, *args, **kwargs):
+        """Return a get_content generator for the newest subreddits.
+
+        The additional parameters are passed directly into
+        :meth:`.get_content`. Note: the `url` parameter cannot be altered.
+
+        """
+        url = self.config['new_subreddits']
+        return self.get_content(url, *args, **kwargs)
+
     def get_popular_reddits(self, *args, **kwargs):
         """Return a get_content generator for the most active subreddits.
 
@@ -1308,7 +1319,9 @@ class ModConfigMixin(AuthenticatedReddit):
                      wiki_edit_age=30, wiki_edit_karma=100,
                      submit_link_label='', submit_text_label='',
                      exclude_banned_modqueue=False, comment_score_hide_mins=0,
-                     public_traffic=False, **kwargs):
+                     public_traffic=False, prev_submit_text_id=None,
+                     spam_comments='low', spam_links='high',
+                     spam_selfposts='high', submit_text='', **kwargs):
         """Set the settings for the given subreddit.
 
         :param subreddit: Must be a subreddit object.
@@ -1332,7 +1345,11 @@ class ModConfigMixin(AuthenticatedReddit):
                 'public_traffic': public_traffic,
                 'show_media': 'on' if show_media else 'off',
                 'submit_link_label': submit_link_label or '',
+                'submit_text': submit_text,
                 'submit_text_label': submit_text_label or '',
+                'spam_comments': spam_comments,
+                'spam_links': spam_links,
+                'spam_selfposts': spam_selfposts,
                 'title': title,
                 'type': subreddit_type,
                 'wiki_edit_age': six.text_type(wiki_edit_age),
@@ -1342,6 +1359,8 @@ class ModConfigMixin(AuthenticatedReddit):
             data['prev_description_id'] = prev_description_id
         if prev_public_description_id is not None:
             data['prev_public_description_id'] = prev_public_description_id
+        if prev_submit_text_id is not None:
+            data['prev_submit_text_id'] = prev_submit_text_id
         if kwargs:
             msg = 'Extra settings fields: {0}'.format(kwargs.keys())
             warn_explicit(msg, UserWarning, '', 0)
@@ -1936,12 +1955,20 @@ class SubmitMixin(AuthenticatedReddit):
 
     @decorators.restrict_access(scope='submit')
     @decorators.require_captcha
-    def submit(self, subreddit, title, text=None, url=None, captcha=None):
+    def submit(self, subreddit, title, text=None, url=None, captcha=None,
+               save=None, send_replies=None):
         """Submit a new link to the given subreddit.
 
         Accepts either a Subreddit object or a str containing the subreddit's
         display name.
 
+        :param save: If True the new Submission will be saved after creation.
+        :param send_replies: Gold Only Feature. If True, inbox replies will be
+            received when people comment on the Submission. If set to None or
+            the currently authenticated user doesn't have gold, then the
+            default of True for text posts and False for link posts will be
+            used.
+
         :returns: The newly created Submission object if the reddit instance
             can access it. Otherwise, return the url to the submission.
 
@@ -1958,6 +1985,10 @@ class SubmitMixin(AuthenticatedReddit):
             data['url'] = url
         if captcha:
             data.update(captcha)
+        if save is not None:
+            data['save'] = save
+        if send_replies is not None:
+            data['sendreplies'] = send_replies
         result = self.request_json(self.config['submit'], data=data,
                                    retry_on_error=False)
         url = result['data']['url']
